@@ -9,9 +9,9 @@ from functools import wraps
 from textwrap import shorten
 from datetime import datetime
 
-DATEFORMAT_STD = "%Y-%m-%d %H:%M:%S,%f"
+DATEFORMAT_STD = "%Y-%m-%d %H:%M:%S"
 DATEFORMAT_DEV = "%H:%M:%S"
-DATEFORMAT_FILE = "%Y-%m-%d_%H-%M-%S,%f"
+DATEFORMAT_FILE = "%Y-%m-%d_%H-%M-%S"
 
 
 def pathmaker(first_segment, *in_path_segments, rev=False):
@@ -145,7 +145,7 @@ class CustomFormatter(logging.Formatter):
 
 def _each_run_file_rotate_handler(in_file_name, in_back_up):
     _date_format = DATEFORMAT_DEV if os.getenv('IS_DEV') == "1" else DATEFORMAT_STD
-    formatter = CustomFormatter(fmt='{asctime} |{levelname:^11}|{threadName:^12}|{lineno:^5}| {name:<50} |{funcName:^30}||--> {message}', datefmt=_date_format, style='{')
+    formatter = CustomFormatter(fmt='{asctime}.%(msecs)03d |{levelname:^11}|{threadName:^12}|{lineno:^5}| {name:<50} |{funcName:^30}||--> {message}', datefmt=_date_format, style='{')
     handler = handlers.RotatingFileHandler(in_file_name, mode='a', backupCount=in_back_up, maxBytes=10 * (1024 * 1024))
     handler.namer = std_namer
     handler.setFormatter(formatter)
